@@ -1,6 +1,6 @@
 #! /bin/bash
 
-# $Id: build.sh,v 1.11 2003/10/21 20:08:09 jt Exp $
+# $Id: build.sh,v 1.13 2007/02/09 12:37:02 jt Exp $
 
 # vim: tabstop=4
 
@@ -24,7 +24,7 @@ PatchDir=CYGWIN-PATCHES
 
 # configure
 configure --prefix=/usr --datadir=/usr/share --mandir=/usr/share/man \
-	--enable-NTLM --with-ssl --enable-fallback=procmail
+	--enable-NTLM --with-ssl --enable-fallback=procmail --sysconfdir=/etc
 
 # make
 make
@@ -35,16 +35,14 @@ make DESTDIR=$TmpDir install
 # strip executables
 find $InstallPrefix -name '*.exe' | xargs strip
 
-# create man cat dirs
-mkdir $ManDir/cat1
-
 # copy Cygwin fetchmail README file
 mkdir -p $CygDocDir
 cp $PatchDir/README $CygDocDir/$pkg-$version.README
 
 # copy fetchmail COPYRIGHT, README, etc. files
-TopFiles=(COPYING FAQ FEATURES INSTALL NEWS NOTES README README.NTLM \
-	README.SSL TODO fetchmail-FAQ.html)
+TopFiles=(ABOUT-NLS COPYING FAQ FEATURES INSTALL NEWS NOTES OLDNEWS README \
+	README.NTLM README.SSL TODO fetchmail-FAQ.html design-notes.html \
+	esrs-design-notes.html fetchmail-features.html todo.html)
 mkdir -p $DocDir
 cp ${TopFiles[*]} $DocDir
 
